==> zio-aws-securityhub_2.13-5.17.115.1-sources.jar: zio/aws/securityhub/model/UpdateSecurityHubConfigurationRequest.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateSecurityHubConfigurationRequest(
    autoEnableControls: Option[Boolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.UpdateSecurityHubConfigurationRequest = {
    import UpdateSecurityHubConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.UpdateSecurityHubConfigurationRequest
      .builder()
      .optionallyWith(
        autoEnableControls.map(value => value: java.lang.Boolean)
      )(_.autoEnableControls)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.UpdateSecurityHubConfigurationRequest.ReadOnly =
    zio.aws.securityhub.model.UpdateSecurityHubConfigurationRequest
      .wrap(buildAwsValue())
}
object UpdateSecurityHubConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.UpdateSecurityHubConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.UpdateSecurityHubConfigurationRequest =
      zio.aws.securityhub.model.UpdateSecurityHubConfigurationRequest(
        autoEnableControls.map(value => value)
      )
    def autoEnableControls: Option[Boolean]
    def getAutoEnableControls: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("autoEnableControls", autoEnableControls)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.UpdateSecurityHubConfigurationRequest
  ) extends zio.aws.securityhub.model.UpdateSecurityHubConfigurationRequest.ReadOnly {
    override val autoEnableControls: Option[Boolean] =
      scala.Option(impl.autoEnableControls()).map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.UpdateSecurityHubConfigurationRequest
  ): zio.aws.securityhub.model.UpdateSecurityHubConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-securityhub_2.13-5.17.163.1-sources.jar: zio/aws/securityhub/model/UpdateSecurityHubConfigurationRequest.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateSecurityHubConfigurationRequest(
    autoEnableControls: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.UpdateSecurityHubConfigurationRequest = {
    import UpdateSecurityHubConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.UpdateSecurityHubConfigurationRequest
      .builder()
      .optionallyWith(
        autoEnableControls.map(value => value: java.lang.Boolean)
      )(_.autoEnableControls)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.UpdateSecurityHubConfigurationRequest.ReadOnly =
    zio.aws.securityhub.model.UpdateSecurityHubConfigurationRequest
      .wrap(buildAwsValue())
}
object UpdateSecurityHubConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.UpdateSecurityHubConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.UpdateSecurityHubConfigurationRequest =
      zio.aws.securityhub.model.UpdateSecurityHubConfigurationRequest(
        autoEnableControls.map(value => value)
      )
    def autoEnableControls: Optional[Boolean]
    def getAutoEnableControls: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("autoEnableControls", autoEnableControls)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.UpdateSecurityHubConfigurationRequest
  ) extends zio.aws.securityhub.model.UpdateSecurityHubConfigurationRequest.ReadOnly {
    override val autoEnableControls: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.autoEnableControls())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.UpdateSecurityHubConfigurationRequest
  ): zio.aws.securityhub.model.UpdateSecurityHubConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}
